@@ -1,20 +1,20 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 import re
 import sys
 
 for line in open(sys.argv[1]):
-    match = re.search('getopt\(argc, argv, "([\w:]*?)"\)', line)
+    match = re.search(r'getopt\(argc, argv, "([\w:]*?)"\)', line)
     if match:
         options = match.group(1)
         break
 else:
     raise RuntimeError
 
-print '#define GETOPT_OPTIONS "%s"' % options
+print('#define GETOPT_OPTIONS "%s"' % options)
 
-print '#define GETOPT_CASE',
+print('#define GETOPT_CASE', end=' ')
 for c in options:
     if c == ':' or c == 'T':
         continue
-    print "case '%c':" % c,
-print
+    print("case '%c':" % c, end=' ')
+print()
